==> haskell-vector-th-unbox-0.2.1.6-31-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vector-th-unbox.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-th-unbox
version: 0.2.1.6
id: vector-th-unbox-0.2.1.6-LZLuOhl72IF7NW8IrRJm9b
key: vector-th-unbox-0.2.1.6-LZLuOhl72IF7NW8IrRJm9b
license: BSD-3-Clause
copyright: © 2012−2015 Liyang HU
maintainer: Liyang HU <vector-th-unbox@liyang.hu>
author: Liyang HU <vector-th-unbox@liyang.hu>
stability: experimental
synopsis: Deriver for Data.Vector.Unboxed using Template Haskell
description:
    A Template Haskell deriver for unboxed vectors, given a pair of coercion
    functions to and from some existing type with an Unbox instance.
    .
    Refer to "Data.Vector.Unboxed.Deriving" for documentation and examples.
category: Data
abi: ba43d1ed182970a0554a89c630fe59d5
exposed: True
exposed-modules:
    Data.Vector.Unboxed.Deriving
import-dirs: /usr/lib/ghc-8.6.5/site-local/vector-th-unbox-0.2.1.6
library-dirs: /usr/lib/ghc-8.6.5/site-local/vector-th-unbox-0.2.1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/vector-th-unbox-0.2.1.6
hs-libraries: HSvector-th-unbox-0.2.1.6-LZLuOhl72IF7NW8IrRJm9b
depends:
    base-4.12.0.0 template-haskell-2.14.0.0
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-vector-th-unbox/html/vector-th-unbox.haddock
haddock-html: /usr/share/doc/haskell-vector-th-unbox/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-th-unbox-0.2.1.7-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vector-th-unbox.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-th-unbox
version: 0.2.1.7
id: vector-th-unbox-0.2.1.7-BOMKxSwBmzmI3R2UcvGXd0
key: vector-th-unbox-0.2.1.7-BOMKxSwBmzmI3R2UcvGXd0
license: BSD-3-Clause
copyright: (c) 2012-2015 Liyang HU
maintainer: Liyang HU <vector-th-unbox@liyang.hu>
author: Liyang HU <vector-th-unbox@liyang.hu>
stability: experimental
synopsis: Deriver for Data.Vector.Unboxed using Template Haskell
description:
    A Template Haskell deriver for unboxed vectors, given a pair of coercion
    functions to and from some existing type with an Unbox instance.
    .
    Refer to "Data.Vector.Unboxed.Deriving" for documentation and examples.
category: Data
abi: cd927a9951c8504401b1cf826492abb1
exposed: True
exposed-modules:
    Data.Vector.Unboxed.Deriving
import-dirs: /usr/lib/ghc-8.6.5/site-local/vector-th-unbox-0.2.1.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/vector-th-unbox-0.2.1.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/vector-th-unbox-0.2.1.7
hs-libraries: HSvector-th-unbox-0.2.1.7-BOMKxSwBmzmI3R2UcvGXd0
depends:
    base-4.12.0.0 template-haskell-2.14.0.0
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-vector-th-unbox/html/vector-th-unbox.haddock
haddock-html: /usr/share/doc/haskell-vector-th-unbox/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
